@@ -1,4 +1,4 @@
-# Copyright Louis Paternault 2017
+# Copyright Louis Paternault 2017-2021
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
@@ -26,7 +26,7 @@ from evariste.setup import Setup
 from evariste.utils import ChangeDir
 import evariste
 
-FORMAT = "[%(threadName)10s-%(name)-20s] %(message)s"
+FORMAT = "%(message)s"
 logging.basicConfig(format=FORMAT)
 LOGGER = logging.getLogger(evariste.__name__)
 
