@@ -1,4 +1,4 @@
-# Copyright Louis Paternault 2015-2020
+# Copyright Louis Paternault 2015-2021
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
@@ -27,5 +27,5 @@ class HtmlImageRenderer(HtmlFileRenderer):
     keyword = "renderer.html.file.image"
     template = "image"
 
-    def match(self, path):
-        return path.as_posix().split(".")[-1].lower() in IMAGE_EXTENSIONS
+    def match(self, filename):
+        return filename.as_posix().split(".")[-1].lower() in IMAGE_EXTENSIONS
