@@ -1,4 +1,4 @@
-# Copyright Louis Paternault 2017-2020
+# Copyright Louis Paternault 2017-2021
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,7 +27,6 @@ class MdwnReadmeRenderer(HtmlReadmeRenderer):
     extensions = ["mdwn", "md"]
 
     def render(self, path, context):
-        """Render file as html code.
-        """
+        """Render file as html code."""
         with open(path, encoding="utf8") as source:
             return markdown.markdown(source.read())
