@@ -1,4 +1,4 @@
-# Copyright Louis Paternault 2016-2020
+# Copyright Louis Paternault 2016-2021
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
@@ -201,6 +201,10 @@ class Tree:
         for sub in sorted(self):
             yield from self[sub].walk(dirs, files)
 
+    def count(self, dirs=False, files=True):
+        """Count the number of files or directories in this tree."""
+        return sum(1 for _ in self.walk(dirs, files))
+
     def prune(self, path):
         """Remove a file.
 
@@ -231,8 +235,7 @@ class Tree:
             self[parts[0]].prune(parts[1:])
 
     def format(self, string):
-        """Format given string, with several variables related to ``self``.
-        """
+        """Format given string, with several variables related to ``self``."""
         suffix = self.from_source.suffix
         if suffix.startswith("."):
             suffix = suffix[1:]
@@ -267,7 +270,7 @@ class Directory(Tree):
 
         self.prune(".evsignore")
 
-        with open(ignorename) as file:
+        with open(ignorename, encoding="utf8") as file:
             for line in file.readlines():
                 line = line.strip()
                 if not line:
@@ -280,13 +283,11 @@ class Directory(Tree):
                         break
                 except ValueError as error:
                     LOGGER.warning(
-                        "Line '{}' has been ignored in file '{}': {}.".format(
-                            line, ignorename, str(error)
-                        )
+                        f"Line '{line}' has been ignored in file '{ignorename}': {error}."
                     )
                     continue
                 for filename in self.from_fs.glob(line):
-                    self.prune(filename.relative_to(self.root.from_fs))
+                    self.prune(filename.relative_to(self.from_fs))
 
     def compile(self):
         """Compile directory."""
@@ -314,10 +315,10 @@ class File(Tree):
                 self.parent.prune(name.format(self.basename))
                 self.parent.prune(self.basename)
 
+    @methodhook()
     def compile(self):
         """Compile file."""
         # pylint: disable=too-many-branches
-        LOGGER.info("Compiling '{}'…".format(self.from_source))
 
         # Find a plugin to compile the file
         # pylint: disable=unsubscriptable-object
@@ -327,7 +328,7 @@ class File(Tree):
                 compiler = self.shared.builder.plugins.get_plugin("action.cached")
             elif self.config["action"]["plugin"] is not None:
                 compiler = self.shared.builder.plugins.get_plugin(
-                    "{}.{}".format("action", self.config["action"]["plugin"])
+                    f"""action.{self.config["action"]["plugin"]}"""
                 )
             else:
                 compiler = self.shared.builder.plugins.match("action", self)
@@ -335,18 +336,19 @@ class File(Tree):
             compiler = self.shared.builder.plugins.get_plugin("action.noplugin")
 
         # Actual compilation
-        with self.shared.builder.plugins.apply_context_hook("compilefile", self):
-            try:
-                self.report = compiler.compile(self)
-            except Exception as error:  # pylint: disable=broad-except
-                if isinstance(error, errors.EvaristeError):
-                    message = str(error)
-                else:
-                    message = (
-                        "Error: Evariste internal error\n\n" + traceback.format_exc()
-                    )
-                LOGGER.error(message)
-                self.report = plugins.action.Report(self, success=False, log=message,)
+        try:
+            self.report = compiler.compile(self)
+        except Exception as error:  # pylint: disable=broad-except
+            if isinstance(error, errors.EvaristeError):
+                message = str(error)
+            else:
+                message = "Error: Evariste internal error\n\n" + traceback.format_exc()
+            LOGGER.error(message)
+            self.report = plugins.action.Report(
+                self,
+                success=False,
+                log=message,
+            )
 
         # Add (optional) dependencies to the file
         # pylint: disable=unsubscriptable-object
@@ -359,12 +361,6 @@ class File(Tree):
                     if self.vcs.is_versionned(name):
                         self.report.depends.add(name)
 
-        # That's all, folks!
-        if self.report.success:
-            LOGGER.info("Compiling '{}': success.".format(self.from_source))
-        else:
-            LOGGER.info("Compiling '{}': failed.".format(self.from_source))
-
     def iter_depends(self):
         """Iterate over dependencies."""
         for path in self.report.depends:
@@ -420,9 +416,7 @@ class File(Tree):
         if len(self.report.full_depends) == 1:
             utils.copy(self.from_fs.as_posix(), (destdir / self.from_source).as_posix())
             return self.from_source
-        archivepath = self.from_source.with_suffix(
-            "{}.{}".format(self.from_source.suffix, "tar.gz")
-        )
+        archivepath = self.from_source.with_suffix(f"{self.from_source.suffix}.tar.gz")
         os.makedirs(os.path.dirname((destdir / archivepath).as_posix()), exist_ok=True)
 
         archive_root, full_depends = common_root(self.report.full_depends)
