@@ -1,6 +1,4 @@
-#!/usr/bin python
-
-# Copyright 2015-2020 Louis Paternault
+# Copyright 2015-2021 Louis Paternault
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -37,8 +35,7 @@ def iter_modules(package):
 
 
 def load_tests(__loader, tests, __ignore):
-    """Load tests (doctests).
-    """
+    """Load tests (doctests)."""
     # Loading doctests
     for module in iter_modules(evariste):
         tests.addTests(doctest.DocTestSuite(module))
